//
// This file is part of the Marble Desktop Globe.
//
// This program is free software licensed under the GNU LGPL. You can
// find a copy of this license in LICENSE.txt in the top directory of
// the source code.
//
// Copyright 2004-2007 Torsten Rahn <tackat@kde.org>"
// Copyright 2007      Inge Wallin  <ingwa@kde.org>"
//

//
// The TextureColorizer maps the Elevationvalues to Legend Colors.
//


#ifndef TEXCOLORIZER_H
#define TEXCOLORIZER_H


#include <QtCore/QString>
#include <QtCore/QList>
#include <QtCore/QVector>
#include <QtGui/QImage>
#include "Quaternion.h"
// #define FLAT_PROJ

typedef struct
{
    uchar  x1;
    uchar  x2;
    uchar  x3;
    uchar  x4;
} GpUint;


typedef union
{
    uint    buffer;
    GpUint  gpuint;
} GpFifo;

class TextureColorizer
{
 public:
    TextureColorizer(const QString&, const QString&);
    virtual ~TextureColorizer(){}
    void colorize(QImage*, const QImage*, const int&, Quaternion);

    /**
     * @brief  Return whether the coordinate grid is visible.
     * @return The coordinate grid visibility.
     */
    bool  showRelief() const
    { 
        return m_showRelief;
    }

    /**
     * @brief  Set whether the coordinate grid overlay is visible
     * @param  visible  visibility of the coordinate grid
     */
    void setShowRelief( bool visible ){ 
        m_showRelief = visible;
    }

 private:
    static const uint  texturepalette[][512];
    bool m_showRelief;
};


#endif
